@@ -3,7 +3,7 @@ BEGIN {
   $Benchmark::Perl::Formance::Analyzer::Tapper::AUTHORITY = 'cpan:SCHWIGON';
 }
 # ABSTRACT: Benchmark::Perl::Formance - analyze results using Tapper backend store
-$Benchmark::Perl::Formance::Analyzer::Tapper::VERSION = '0.005';
+$Benchmark::Perl::Formance::Analyzer::Tapper::VERSION = '0.006';
 use 5.010;
 
 use Moose;
@@ -99,8 +99,10 @@ sub _get_chart
 {
         my ($self, $chartname) = @_;
 
+        require File::Slurper;
+
         my $filename = dist_dir('Benchmark-Perl-Formance-Analyzer')."/chartqueries/perlformance/$chartname.json";
-        my $json = "".File::Slurp::read_file($filename);
+        my $json = File::Slurper::read_text($filename);
         if ($self->debug) {
                 say STDERR "READ: $chartname - $filename";
                 say STDERR "JSON:\n$json";
